==> jc-1.4.0.tar.gz: soot/jbuddy/SWIGTYPE__5fp__5fint.h <==
// public class soot.jbuddy.SWIGTYPE_p_int

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 41dbfbcbbd3dcb31 soot_jbuddy_SWIGTYPE__5fp__5fint

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jbuddy_SWIGTYPE__5fp__5fint_H_
#define _JC_soot_jbuddy_SWIGTYPE__5fp__5fint_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$object;

// Typedefs
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$sub_refs	_jc_soot_jbuddy_SWIGTYPE__5fp__5fint$sub_refs;
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$sub_nonrefs	_jc_soot_jbuddy_SWIGTYPE__5fp__5fint$sub_nonrefs;
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$refs	_jc_soot_jbuddy_SWIGTYPE__5fp__5fint$refs;
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$nonrefs	_jc_soot_jbuddy_SWIGTYPE__5fp__5fint$nonrefs;
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$object	_jc_soot_jbuddy_SWIGTYPE__5fp__5fint$object;

typedef const struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$vmethods	_jc_soot_jbuddy_SWIGTYPE__5fp__5fint$vmethods;
typedef const struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$vtable	_jc_soot_jbuddy_SWIGTYPE__5fp__5fint$vtable;
typedef const struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$vtype	_jc_soot_jbuddy_SWIGTYPE__5fp__5fint$vtype;

// Constructors
extern void _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$object *);
extern void _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$method$_init$e037f92e255e7cc9(_jc_env *, struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$object *, jlong, jboolean);

// Static methods
extern jlong _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$method$getCPtr$9a3c11c72279fce8(_jc_env *, struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$object *);

// Virtual methods structure
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$vmethods {
};

// Vtable
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jbuddy_SWIGTYPE__5fp__5fint$vmethods	soot_jbuddy_SWIGTYPE__5fp__5fint;
};

// Vtype
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$vtype {
	_jc_type			type;
	_jc_soot_jbuddy_SWIGTYPE__5fp__5fint$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$refs {
    _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$sub_refs	soot_jbuddy_SWIGTYPE__5fp__5fint;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$sub_nonrefs {
	jlong	swigCPtr;
};

// Non-reference instance fields (object)
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$sub_nonrefs	soot_jbuddy_SWIGTYPE__5fp__5fint;
};

// Object instance structure
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$object {
	_jc_soot_jbuddy_SWIGTYPE__5fp__5fint$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jbuddy_SWIGTYPE__5fp__5fint$vtype	*vtype;
	_jc_soot_jbuddy_SWIGTYPE__5fp__5fint$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$vtype _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jbuddy_SWIGTYPE__5fp__5fint, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$class_object;

#endif	/* _JC_soot_jbuddy_SWIGTYPE__5fp__5fint_H_ */

==> jc-1.4.6.tar.gz: soot/jbuddy/SWIGTYPE__5fp__5fint.h <==
// public class soot.jbuddy.SWIGTYPE_p_int

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 41dbfbcbbd3dcb31 soot_jbuddy_SWIGTYPE__5fp__5fint

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jbuddy_SWIGTYPE__5fp__5fint_H_
#define _JC_soot_jbuddy_SWIGTYPE__5fp__5fint_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$object;

// Typedefs
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$sub_refs	_jc_soot_jbuddy_SWIGTYPE__5fp__5fint$sub_refs;
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$sub_nonrefs	_jc_soot_jbuddy_SWIGTYPE__5fp__5fint$sub_nonrefs;
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$refs	_jc_soot_jbuddy_SWIGTYPE__5fp__5fint$refs;
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$nonrefs	_jc_soot_jbuddy_SWIGTYPE__5fp__5fint$nonrefs;
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$object	_jc_soot_jbuddy_SWIGTYPE__5fp__5fint$object;

typedef const struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$vmethods	_jc_soot_jbuddy_SWIGTYPE__5fp__5fint$vmethods;
typedef const struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$vtable	_jc_soot_jbuddy_SWIGTYPE__5fp__5fint$vtable;
typedef const struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$vtype	_jc_soot_jbuddy_SWIGTYPE__5fp__5fint$vtype;

// Constructors
extern void _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$method$_init$e037f92e255e7cc9(_jc_env *, struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$object *, jlong, jboolean) _JC_JCNI_ATTR;

// Static methods
extern jlong _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$method$getCPtr$9a3c11c72279fce8(_jc_env *, struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$vmethods {
};

// Vtable
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jbuddy_SWIGTYPE__5fp__5fint$vmethods	soot_jbuddy_SWIGTYPE__5fp__5fint;
};

// Vtype
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$vtype {
	_jc_type			type;
	_jc_soot_jbuddy_SWIGTYPE__5fp__5fint$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$refs {
    _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$sub_refs	soot_jbuddy_SWIGTYPE__5fp__5fint;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$sub_nonrefs {
	jlong	swigCPtr;
};

// Non-reference instance fields (object)
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$sub_nonrefs	soot_jbuddy_SWIGTYPE__5fp__5fint;
};

// Object instance structure
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$object {
	_jc_soot_jbuddy_SWIGTYPE__5fp__5fint$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jbuddy_SWIGTYPE__5fp__5fint$vtype	*vtype;
	_jc_soot_jbuddy_SWIGTYPE__5fp__5fint$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$vtype _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jbuddy_SWIGTYPE__5fp__5fint, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jbuddy_SWIGTYPE__5fp__5fint$class_object;

#endif	/* _JC_soot_jbuddy_SWIGTYPE__5fp__5fint_H_ */
